@@ -10,7 +10,7 @@ use DBI;
 use Data::PowerSet;
 use IO::File;
 
-our $VERSION = '0.03';
+our $VERSION = '0.0301';
 
 
 
@@ -43,16 +43,15 @@ sub _init {
 
     # Set lex if given data.
     if ( $self->{file} && -e $self->{file} ) {
-        $self->fetch_lex;
+        $self->_fetch_lex;
     }
     elsif( $self->{dbname} )
     {
-        $self->db_fetch;
+        $self->_db_fetch;
     }
 }
 
-
-sub fetch_lex {
+sub _fetch_lex {
     my $self = shift;
 
     # Open the given file for reading...
@@ -70,8 +69,7 @@ sub fetch_lex {
     return $self->{lex};
 }
 
-
-sub db_fetch {
+sub _db_fetch {
     my $self = shift;
 
     my $dsn = "DBI:$self->{dbtype}:$self->{dbname};$self->{dbhost}";
@@ -362,7 +360,7 @@ Lingua::Word::Parser - Parse a word into known and unknown parts
 
 =head1 VERSION
 
-version 0.03
+version 0.0301
 
 =head1 SYNOPSIS
 
@@ -371,16 +369,19 @@ version 0.03
     word => 'abioticaly',
     file => 'eg/lexicon.dat',
  );
- # Or with a localhost database source:
- my $p = Lingua::Word::Parser->new(
+
+ # Or with a database source:
+ $p = Lingua::Word::Parser->new(
     word   => 'abioticaly',
     dbname => 'fragments',
     dbuser => 'akbar',
-    dbpass => '0p3n53454m3',
+    dbpass => 's3kr1+',
  );
+
  my ($known) = $p->knowns;
  my $combos  = $p->power;
  my $scored  = $p->score;
+
  # The best guess is the last sorted score-set:
  warn Dumper $scored->{ [ sort keys %$score ]->[-1] };
 
@@ -388,6 +389,23 @@ version 0.03
 
 A C<Lingua::Word::Parser> breaks a word into known affixes.
 
+A (word-part => regular-expression) lexicon file must have lines of
+the form:
+
+ a(?=\w)        opposite
+ ab(?=\w)       away
+ (?<=\w)o(?=\w) combining
+ (?<=\w)tic     possessing
+
+A database lexicon must have (affix, definition) records of the form:
+
+         affix     definition
+  -----------------------------
+         a(?=\w)   opposite
+         ab(?=\w)  away
+  (?<=\w)o(?=\w)   combining
+  (?<=\w)tic       possessing
+
 =head1 METHODS
 
 =head2 new()
@@ -398,32 +416,13 @@ Create a new C<Lingua::Word::Parser> object.
 
 Arguments and defaults:
 
-  word: undef
-  lex:  undef
-
-=head2 fetch_lex()
-
-Populate word-part => regular-expression lexicon.
-
-This file has lines of the form:
-
- a(?=\w) opposite
- ab(?=\w) away
- (?<=\w)o(?=\w) combining
- (?<=\w)tic possessing
-
-=head2 db_fetch()
-
-Populate the lexicon from a database source called C<`fragments`>.
-
-This database table has records of the form:
-
-         affix     definition
-  -----------------------------
-         a(?=\w)   opposite
-         ab(?=\w)  away
-  (?<=\w)o(?=\w)   combining
-  (?<=\w)tic       possessing
+  word:   undef
+  lex:    undef
+  dbuser: undef
+  dbpass: undef
+  dbname: undef
+  dbtype: mysql
+  dbhost: localhost
 
 =head2 knowns()
 
